/***********************************************************************************************************************
 *
 * blueBill Stats
 * Copyright (C) 2011-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile/
 * SCM: http://java.net/hg/bluebill-server~stats-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.stats.rest.v1;

import it.tidalwave.bluebill.stats.domain.PingDao;
import it.tidalwave.bluebill.stats.domain.Ping;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Nonnull;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Configurable;
import static javax.ws.rs.core.MediaType.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: PingsV1.java,v ee93ae20f71a 2011/07/15 23:40:10 fabrizio $
 *
 **********************************************************************************************************************/
@Configurable(preConstruction=true) @Path("v1/ping") @Slf4j
public class PingsV1 
  {
    @Inject @Nonnull
    private PingDao dao; 
    
    @GET @Produces({APPLICATION_JSON, APPLICATION_XML})
    public List<PingV1> getPings() throws IOException
      {
        log.info("getPings()");
        final List<PingV1> result = new ArrayList<PingV1>();
        
        for (final Ping ping : dao.findPings().results())
          {
            log.trace(">>>> {}", ping);
            result.add(new PingV1(ping.getTimestamp().toDate(), 
                                  ping.getIpAddress(), 
                                  ping.getInstallId(), 
                                  ping.getAppVersion(),
                                  ping.getOsVersion(),
                                  ping.getJavaVersion(),
                                  ping.getUserLanguage(), 
                                  ping.getUserRegion(), 
                                  ping.getBoard(), 
                                  ping.getBrand(), 
                                  ping.getDevice(), 
                                  ping.getModel(), 
                                  ping.getProduct(), 
                                  ping.getVersionIncremental(), 
                                  ping.getVersionRelease(), 
                                  ping.getVersionSDK()));
          }
        
        return result;
      }
  }  